==> cmd-0.0.7.tar.gz: README.md <==
[![cmd](https://img.shields.io/pub/v/cmd.svg?label=cmd&color=blue)](https://pub.dev/packages/cmd)
[![Points](https://img.shields.io/pub/points/cmd)](https://pub.dev/packages/cmd/score)
[![Popularity](https://img.shields.io/pub/popularity/cmd)](https://pub.dev/packages/cmd/score)
[![Likes](https://img.shields.io/pub/likes/cmd)](https://pub.dev/packages/cmd/score)
[![Telegram](https://img.shields.io/badge/Telegram--blue?logo=telegram&logoColor=white)](https://t.me/UsamaSarwar)
[![WhatsApp](https://img.shields.io/badge/WhatsApp--tgreen?logo=whatsapp&logoColor=white)](https://wa.me/923100007773)
[![Contribute Now](https://img.shields.io/badge/Contribute--blue?logo=Github&logoColor=white)](https://github.com/UsamaSarwar/cmd/blob/main/flutter/CONTRIBUTING.md)
[![Donate Now](https://img.shields.io/badge/Donate--blue?logo=buy-me-a-coffee&logoColor=white)](https://www.buymeacoffee.com/UsamaSarwar)

<img align="left" alt="flutter cmd" src="https://raw.githubusercontent.com/UsamaSarwar/cmd/main/flutter/assets/path.png" height="auto" width ="30%"/>
<p align="justify">
Flutter, a mobile development UI kit managed by Google comes with the handy CLI (Command Line Interface). It lets you do the same tasks that you perform using IDE. CMD package helps you quickly running the common CLI commands that are used in almost all Flutter projects by running pre-written scripts. Flutter developers find it difficult to type commands again and again and sometimes you need to run a series of commands one after another. This is where CMD package is helpful. Flutter's <b>cmd</b> package helps developers to save time by running scripts for performing the below operations:
</p>

<img align="right" alt="flutter cmd" src="https://raw.githubusercontent.com/UsamaSarwar/cmd/main/flutter/assets/coding.gif" height="auto" width ="150"/>

- [doctor](https://raw.githubusercontent.com/UsamaSarwar/cmd/main/flutter/cmd/doctor.sh)
- [run](https://raw.githubusercontent.com/UsamaSarwar/cmd/main/flutter/cmd/run.sh)
- [build](https://raw.githubusercontent.com/UsamaSarwar/cmd/main/flutter/cmd/build.sh)
- more coming soon...

## Installation
Add **cmd** as dev_dependency by running the command below:
```bash
flutter pub add -d cmd
```

**OR** 

Add **cmd** this in your `pubspec.yaml`:

```yaml
dev_dependencies:
  cmd:
```

Run the following commands below to install **cmd**:

```bash
flutter pub get
flutter pub run cmd:install
```

In your project root directory you will find a folder **cmd** that contains all available scripts.

<img align="right" alt="FAQs" src="https://raw.githubusercontent.com/UsamaSarwar/cmd/main/flutter/assets/faq.png" height="auto" width ="30%"/>

```bash
├── project
│   ├── cmd
│   │   ├── build.sh
│   │   ├── doctor.sh
│   │   ├── run.sh
```

## Usage in VS Code 🧑🏻‍💻

- Install [Code Runner](https://marketplace.visualstudio.com/items?itemName=formulahendry.code-runner) Extension
- Right click on Script you want to execute and select `Run Code`
- Alternatively use these short keys <kbd>Ctrl</kbd> + <kbd>Alt</kbd> + <kbd>N</kbd> when the script is opened.

## Contribution 💙
You are warmly welcome for contributing **cmd** package. You may add single line scripts or batch scripts such as `cmd/build.sh`. Checkout this [contribution guide.](https://github.com/UsamaSarwar/cmd/blob/main/flutter/CONTRIBUTING.md)

<p align="center"> <img src="https://raw.githubusercontent.com/UsamaSarwar/cmd/main/flutter/assets/contribution.svg" alt="cmd contributions" /> </p>

<p align="center">Open Source Contributor from <b>Punjab, Pakistan</b> 🇵🇰 </p>
<div align="center"><br>
<p><a href="https://www.buymeacoffee.com/UsamaSarwar"> <img align="center" src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" height="40" width="168" alt="Buy me a Coffee ☕" /></a></p>
</div>

<br><p align="center"> <img src="https://raw.githubusercontent.com/UsamaSarwar/cmd/main/flutter/assets/cmd.jpg" alt="Flutter cmd package" /> </p>

==> cmd-0.0.8.tar.gz: README.md <==
[![cmd](https://img.shields.io/pub/v/cmd.svg?label=cmd&color=blue)](https://pub.dev/packages/cmd)
[![Points](https://img.shields.io/pub/points/cmd)](https://pub.dev/packages/cmd/score)
[![Popularity](https://img.shields.io/pub/popularity/cmd)](https://pub.dev/packages/cmd/score)
[![Likes](https://img.shields.io/pub/likes/cmd)](https://pub.dev/packages/cmd/score)
[![Telegram](https://img.shields.io/badge/Telegram--blue?logo=telegram&logoColor=white)](https://t.me/UsamaSarwar)
[![WhatsApp](https://img.shields.io/badge/WhatsApp--tgreen?logo=whatsapp&logoColor=white)](https://wa.me/923100007773)
[![Contribute Now](https://img.shields.io/badge/Contribute--blue?logo=Github&logoColor=white)](https://github.com/UsamaSarwar/flutter/blob/main/pub/cmd/CONTRIBUTING.md)
[![Donate Now](https://img.shields.io/badge/Donate--blue?logo=buy-me-a-coffee&logoColor=white)](https://www.buymeacoffee.com/UsamaSarwar)

<img align="left" alt="flutter cmd" src="https://raw.githubusercontent.com/UsamaSarwar/flutter/main/pub/cmd/assets/path.png" height="auto" width ="30%"/>
<p align="justify">
Flutter, a mobile development UI kit managed by Google comes with the handy CLI (Command Line Interface). It lets you do the same tasks that you perform using IDE. CMD package helps you quickly running the common CLI commands that are used in almost all Flutter projects by running pre-written scripts. Flutter developers find it difficult to type commands again and again and sometimes you need to run a series of commands one after another. This is where CMD package is helpful. Flutter's <b>cmd</b> package helps developers to save time by running scripts for performing the below operations:
</p>

<img align="right" alt="flutter cmd" src="https://raw.githubusercontent.com/UsamaSarwar/flutter/main/pub/cmd/assets/coding.gif" height="auto" width ="150"/>

- [doctor](https://raw.githubusercontent.com/UsamaSarwar/flutter/main/pub/cmd/cmd/doctor.sh)
- [run](https://raw.githubusercontent.com/UsamaSarwar/flutter/main/pub/cmd/cmd/run.sh)
- [build](https://raw.githubusercontent.com/UsamaSarwar/flutter/main/pub/cmd/cmd/build.sh)
- more coming soon...

## Installation

Add **cmd** as dev_dependency by running the command below:

```bash
flutter pub add -d cmd
```

**OR**

Add **cmd** this in your `pubspec.yaml`:

```yaml
dev_dependencies:
  cmd:
```

Run the following commands below to install **cmd**:

```bash
flutter pub get
flutter pub run cmd:install
```

In your project root directory you will find a folder **cmd** that contains all available scripts.

<img align="right" alt="FAQs" src="https://raw.githubusercontent.com/UsamaSarwar/flutter/main/pub/cmd/assets/faq.png" height="auto" width ="30%"/>

```bash
├── project
│   ├── cmd
│   │   ├── build.sh
│   │   ├── doctor.sh
│   │   ├── run.sh
```

## Usage in VS Code 🧑🏻‍💻

- Install [Code Runner](https://marketplace.visualstudio.com/items?itemName=formulahendry.code-runner) Extension
- Right click on Script you want to execute and select `Run Code`
- Alternatively use these short keys <kbd>Ctrl</kbd> + <kbd>Alt</kbd> + <kbd>N</kbd> when the script is opened.

## Contribution 💙

You are warmly welcome for contributing **cmd** package. You may add single line scripts or batch scripts such as `cmd/build.sh`. Checkout this [contribution guide.](https://github.com/UsamaSarwar/flutter/blob/main/pub/cmd/CONTRIBUTING.md)

<p align="center"> <img src="https://raw.githubusercontent.com/UsamaSarwar/flutter/main/pub/cmd/assets/contribution.svg" alt="cmd contributions" /> </p>

<p align="center">Open Source Contributor from <b>Punjab, Pakistan</b> 🇵🇰 </p>
<div align="center"><br>
<p><a href="https://www.buymeacoffee.com/UsamaSarwar"> <img align="center" src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" height="40" width="168" alt="Buy me a Coffee ☕" /></a></p>
</div>

<br><p align="center"> <img src="https://raw.githubusercontent.com/UsamaSarwar/flutter/main/pub/cmd/assets/cmd.jpg" alt="Flutter cmd package" /> </p>
